<div align="center">

[![Logo Pokémon](https://raw.githubusercontent.com/LassaInora/Tyradex/refs/heads/main/assets/img/logo.png)](https://tyradex.app/)
# Tyradex for Python
[![LassaInora - Tyradex](https://img.shields.io/static/v1?label=LassaInora&message=Tyradex&color=yellow&logo=github)](https://github.com/LassaInora/Tyradex "Go to GitHub repo")
[![GitHub tag](https://img.shields.io/github/tag/LassaInora/Tyradex?include_prereleases=&sort=semver&color=orange)](https://github.com/LassaInora/Tyradex/releases/)
[![stars - Tyradex](https://img.shields.io/github/stars/LassaInora/Tyradex?style=social)](https://github.com/LassaInora/Tyradex)
[![forks - Tyradex](https://img.shields.io/github/forks/LassaInora/Tyradex?style=social)](https://github.com/LassaInora/Tyradex)

[![PyPI version](https://badge.fury.io/py/Tyradex.svg)](https://badge.fury.io/py/Tyradex)
[![Supported Versions](https://img.shields.io/pypi/pyversions/Tyradex.svg)](https://pypi.org/project/Tyradex)

___

[![Click for README - French](https://img.shields.io/badge/Click_for_README-Français-red)](README_FRENCH.md)

---

</div>

# Overview
This Python script interacts with the [Tyradex API](https://tyradex.app/) to retrieve detailed information about 
Pokémon, Generation and Pokémon types. It is designed to provide easy access to details such as Pokédex ID, generation, 
category, statistics, etc., for individual Pokémon or types. The script is organized into classes representing different 
aspects of Pokémon data and includes functions to obtain lists of all Pokémon and types.

# How to use

## Installation
- Unix/ macOS : `python3 -m pip install --upgrade Tyradex`
- Windows : `py -m pip install --upgrade Tyradex`

 ---
WIP